@@ -194,7 +194,17 @@ Print to filehandles:
     $top->print_body(\*STDOUT);
 
 Stringify... note that C<stringify_xx> can also be written C<xx_as_string>;
-the methods are synonymous, and neither form will be deprecated:
+the methods are synonymous, and neither form will be deprecated.
+
+If you set the variable $MIME::Entity::BOUNDARY_DELIMITER to a string,
+that string will be used as the line-end delimiter on output.  If it is not set,
+the line ending will be a newline character (\n)
+
+NOTE that $MIME::Entity::BOUNDARY_DELIMITER only applies to structural
+parts of the MIME data generated by this package and to the Base64
+encoded output; if a part internally uses a different line-end
+delimiter and is output as-is, the line-ending is not changed to match
+$MIME::Entity::BOUNDARY_DELIMITER.
 
     ### Stringify the entire message:
     print $top->stringify;              ### or $top->as_string
@@ -245,7 +255,7 @@ use MIME::Decoder;
 #------------------------------
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.506";
+$VERSION = "5.511";
 
 ### Boundary counter:
 my $BCount = 0;
@@ -264,7 +274,7 @@ qw(
    );
 
 ### Fallback preamble and epilogue:
-my $DefPreamble = [ "This is a multi-part message in MIME format...\n" ];
+my $DefPreamble = [ "This is a multi-part message in MIME format..." ];
 my $DefEpilogue = [ ];
 
 
@@ -485,6 +495,11 @@ or an array reference (whose elements are joined together to make
 the actual scalar).  The body is opened on the data using
 MIME::Body::InCore.
 
+Note that for text parts, the Data scalar or array is assumed to be
+encoded in a suitable character encoding (as if by C<Encode::encode>)
+rather than a native Perl string.  The encoding you use must, of
+course, match the C<charset> option of the C<MIME-Type> header.
+
 =item Description
 
 I<Optional.>
@@ -767,6 +782,7 @@ or raw data (via read()).
 
 sub body {
 	my ($self, $value) = @_;
+	my $boundary_delimiter = $MIME::Entity::BOUNDARY_DELIMITER || "\n";
 	if (@_ > 1) {      ### setting body line(s)...
 		croak "you cannot use body() to set the encoded contents\n";
 	} else {
@@ -776,7 +792,7 @@ sub body {
 		close($fh);
 		my @ary = split(/\n/, $output);
 		# Each line needs the terminating newline
-		@ary = map { "$_\n" } @ary;
+		@ary = map { "$_$boundary_delimiter" } @ary;
 
 		return \@ary;
 	}
@@ -1383,6 +1399,7 @@ sub sign {
     my %params = @_;
     my $io;
 
+    my $boundary_delimiter = $MIME::Entity::BOUNDARY_DELIMITER || "\n";
     ### If multipart and not attaching, try to sign our first part:
     if ($self->is_multipart and !$params{Attach}) {
 	return $self->parts(0)->sign(@_);
@@ -1429,8 +1446,8 @@ sub sign {
 	my $line;
 	$io = $self->open("w") or croak("open: $!");
 	foreach $line (@body) { $io->print($line) };      ### body data
-	(($body[-1]||'') =~ /\n\Z/) or $io->print("\n");  ### ensure final \n
-	$io->print("-- \n$sig");                          ### separator + sig
+	(($body[-1]||'') =~ /\n\Z/) or $io->print($boundary_delimiter);  ### ensure final \n
+	$io->print("-- $boundary_delimiter$sig");                          ### separator + sig
 	$io->close or croak("close: $!");
 	return 1;         ### done!
     }
@@ -1764,11 +1781,12 @@ some sort of email handler, it's up to you to save this information.
 use Symbol;
 sub print {
     my ($self, $out) = @_;
+    my $boundary_delimiter = $MIME::Entity::BOUNDARY_DELIMITER || "\n";
     $out = select if @_ < 2;
     $out = Symbol::qualify($out,scalar(caller)) unless ref($out);
 
     $self->print_header($out);   ### the header
-    $out->print("\n");
+    $out->print($boundary_delimiter);
     $self->print_body($out);     ### the "stuff after the header"
 }
 
@@ -1809,6 +1827,7 @@ sub print_body {
     my ($self, $out) = @_;
     $out ||= select;
     my ($type) = split '/', lc($self->mime_type);  ### handle by MIME type
+    my $boundary_delimiter = $MIME::Entity::BOUNDARY_DELIMITER || "\n";
 
     ### Multipart...
     if ($type eq 'multipart') {
@@ -1819,26 +1838,26 @@ sub print_body {
 	if (defined $plines) {
 	    # Defined, so output the preamble if it exists (avoiding additional
 	    # newline as per ticket 60931)
-	    $out->print( join('', @$plines) . "\n") if (@$plines > 0);
+	    $out->print( join('', @$plines) . $boundary_delimiter) if (@$plines > 0);
 	} else {
 	    # Undefined, so use default preamble
-	    $out->print( join('', @$DefPreamble) . "\n" );
+	    $out->print( join('', @$DefPreamble) . $boundary_delimiter . $boundary_delimiter );
 	}
 
 	### Parts:
 	my $part;
 	foreach $part ($self->parts) {
-	    $out->print("--$boundary\n");
+	    $out->print("--$boundary$boundary_delimiter");
 	    $part->print($out);
-	    $out->print("\n");           ### needed for next delim/close
+	    $out->print($boundary_delimiter);           ### needed for next delim/close
 	}
-	$out->print("--$boundary--\n");
+	$out->print("--$boundary--$boundary_delimiter");
 
 	### Epilogue:
 	my $epilogue = join('', @{ $self->epilogue || $DefEpilogue });
 	if ($epilogue ne '') {
 	    $out->print($epilogue);
-	    $out->print("\n") if ($epilogue !~ /\n\Z/);  ### be nice
+	    $out->print($boundary_delimiter) if ($epilogue !~ /\n\Z/);  ### be nice
 	}
     }
 
@@ -1849,7 +1868,7 @@ sub print_body {
 	my $need_sep = 0;
 	my $part;
 	foreach $part ($self->parts) {
-	    $out->print("\n\n") if $need_sep++;
+	    $out->print("$boundary_delimiter$boundary_delimiter") if $need_sep++;
 	    $part->print($out);
 	}
     }
@@ -2250,7 +2269,7 @@ L<MIME::Tools>, L<MIME::Head>, L<MIME::Body>, L<MIME::Decoder>, L<Mail::Internet
 =head1 AUTHOR
 
 Eryq (F<eryq@zeegee.com>), ZeeGee Software Inc (F<http://www.zeegee.com>).
-Dianne Skoll (dfs@roaringpenguin.com) http://www.roaringpenguin.com
+Dianne Skoll (dianne@skoll.ca)
 
 All rights reserved.  This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
